'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// Arrays of colours should have pillar colors first
// e.g. for sport:
// const [sport300, sport400, sport500, sport600, sport800] = colors.blue
const colors = {
    reds: [
        '#660505',
        '#8B0000',
        '#AB0613',
        '#C70000',
        '#FF5943',
        '#FF9081',
        '#FFBAC8',
        '#FFF4F2', //news-800
    ],
    oranges: [
        '#672005',
        '#8D2700',
        '#C74600',
        '#E05E00',
        '#FF7F0F',
        '#FF9941',
        '#F9B376',
        '#FEF9F5', //opinion-800
    ],
    blues: [
        '#003C60',
        '#004E7C',
        '#005689',
        '#0077B6',
        '#00B2FF',
        '#90DCFF',
        '#F1F8FC',
        '#001536',
        '#041F4A',
        '#052962',
        '#506991',
        '#C1D8FC', //brand-800
    ],
    browns: [
        '#2B2625',
        '#3E3323',
        '#574835',
        '#6B5840',
        '#866D50',
        '#A1845C',
        '#EACCA0',
        '#E7D4B9',
        '#EFE8DD',
        '#FBF6EF', //culture-800
    ],
    pinks: [
        '#510043',
        '#650054',
        '#7D0068',
        '#BB3B80',
        '#F37ABC',
        '#FFABDB',
        '#FEC8D3',
        '#FEEEF7', //lifestyle-800
    ],
    yellows: [
        '#F3C100',
        '#FFD900',
        '#FFE500', //brandAlt-400
    ],
    greens: [
        '#185E36',
        '#22874D',
        '#58D08B',
        '#0C7A73',
        '#65A897',
        '#69D1CA', //labs-400
    ],
    grays: [
        '#000000',
        '#121212',
        '#1A1A1A',
        '#333333',
        '#606060',
        '#707070',
        '#999999',
        '#DCDCDC',
        '#EDEDED',
        '#F6F6F6',
        '#FFFFFF', //neutral-100
    ],
    special: [
        '#222527',
        '#303538',
        '#3F464A',
        '#595C5F',
        '#9DA0A2',
        '#ABC2C9',
        '#E4E5E8',
        '#EFF1F2',
        '#2B2B2A',
        '#B9300A',
        '#FF663D',
        '#EBE6E1',
        '#F5F0EB', //specialReportAlt-800
    ],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette)
 *
 * Colour palette organised by type e.g. 'error', or pillar e.g. 'opinion'
 */
const palette = {
    brand: {
        100: colors.blues[7],
        300: colors.blues[8],
        400: colors.blues[9],
        500: colors.blues[3],
        600: colors.blues[10],
        800: colors.blues[11],
    },
    brandAlt: {
        200: colors.yellows[0],
        300: colors.yellows[1],
        400: colors.yellows[2],
    },
    neutral: {
        0: colors.grays[0],
        7: colors.grays[1],
        10: colors.grays[2],
        20: colors.grays[3],
        38: colors.grays[4],
        46: colors.grays[5],
        60: colors.grays[6],
        86: colors.grays[7],
        93: colors.grays[8],
        97: colors.grays[9],
        100: colors.grays[10],
    },
    error: {
        400: colors.reds[3],
        500: colors.reds[5],
    },
    success: {
        400: colors.greens[1],
        500: colors.greens[2],
    },
    news: {
        100: colors.reds[0],
        200: colors.reds[1],
        300: colors.reds[2],
        400: colors.reds[3],
        500: colors.reds[4],
        550: colors.reds[5],
        600: colors.reds[6],
        800: colors.reds[7],
    },
    opinion: {
        100: colors.oranges[0],
        200: colors.oranges[1],
        /**
         * @deprecated, use opinion[400]
         */
        300: colors.oranges[2],
        400: colors.oranges[2],
        450: colors.oranges[3],
        500: colors.oranges[4],
        550: colors.oranges[5],
        600: colors.oranges[6],
        800: colors.oranges[7],
    },
    sport: {
        100: colors.blues[0],
        200: colors.blues[1],
        300: colors.blues[2],
        400: colors.blues[3],
        500: colors.blues[4],
        600: colors.blues[5],
        800: colors.blues[6],
    },
    culture: {
        50: colors.browns[0],
        100: colors.browns[1],
        200: colors.browns[2],
        300: colors.browns[3],
        /**
         * @deprecated, use culture[400]
         */
        350: colors.browns[4],
        400: colors.browns[4],
        450: colors.browns[5],
        500: colors.browns[6],
        600: colors.browns[7],
        700: colors.browns[8],
        800: colors.browns[9],
    },
    lifestyle: {
        100: colors.pinks[0],
        200: colors.pinks[1],
        300: colors.pinks[2],
        400: colors.pinks[3],
        450: colors.pinks[4],
        500: colors.pinks[5],
        600: colors.pinks[6],
        800: colors.pinks[7],
    },
    labs: {
        200: colors.greens[3],
        300: colors.greens[4],
        400: colors.greens[5],
    },
    specialReport: {
        100: colors.special[0],
        200: colors.special[1],
        300: colors.special[2],
        400: colors.special[3],
        450: colors.special[4],
        500: colors.special[5],
        700: colors.special[6],
        800: colors.special[7],
    },
    specialReportAlt: {
        100: colors.special[8],
        200: colors.special[9],
        300: colors.special[10],
        700: colors.special[11],
        800: colors.special[12],
    },
    focus: {
        400: colors.blues[3],
    },
};
// Hover colours are snowflakes as they are manipulations of colours from the
// main palette.
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/9280ee)
 *
 * Default theme background colours
 *
 * @deprecated Use the `palette` export instead
 */
const background = {
    primary: palette.neutral[100],
    secondary: palette.neutral[97],
    inverse: palette.neutral[10],
    ctaPrimary: palette.brand[400],
    ctaPrimaryHover: '#234B8A',
    ctaSecondary: palette.brand[800],
    ctaSecondaryHover: '#ACC9F7',
    ctaTertiaryHover: '#E5E5E5',
    input: palette.neutral[100],
    inputChecked: palette.brand[500],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/63cc10)
 *
 * Brand theme background colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandBackground = {
    primary: palette.brand[400],
    inputChecked: palette.neutral[100],
    ctaPrimary: palette.neutral[100],
    ctaPrimaryHover: '#E0E0E0',
    ctaSecondary: palette.brand[600],
    ctaSecondaryHover: '#234B8A',
    ctaTertiaryHover: palette.brand[300],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/743232)
 *
 * Alternative brand theme background colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandAltBackground = {
    primary: palette.brandAlt[400],
    ctaPrimary: palette.neutral[7],
    ctaPrimaryHover: '#454545',
    ctaSecondary: palette.brandAlt[200],
    ctaSecondaryHover: '#F2AE00',
    ctaTertiaryHover: '#FFD213',
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/69c92f)
 *
 * Default theme border colours
 *
 * @deprecated Use the `palette` export instead
 */
const border = {
    primary: palette.neutral[60],
    secondary: palette.neutral[86],
    success: palette.success[400],
    error: palette.error[400],
    ctaTertiary: palette.brand[400],
    input: palette.neutral[60],
    inputChecked: palette.brand[500],
    inputHover: palette.brand[500],
    inputActive: palette.brand[500],
    focusHalo: palette.focus[400],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/04883b)
 *
 * Brand theme border colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandBorder = {
    primary: palette.brand[600],
    secondary: palette.brand[600],
    success: palette.success[500],
    error: palette.error[500],
    ctaTertiary: palette.neutral[100],
    input: palette.brand[800],
    inputChecked: palette.neutral[100],
    inputHover: palette.neutral[100],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/b/21c6cc)
 *
 * Alternative brand theme border colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandAltBorder = {
    ctaTertiary: palette.neutral[7],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/593cc9)
 *
 * Default theme line colours
 *
 * @deprecated Use the `palette` export instead
 */
const line = {
    primary: palette.neutral[86],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/66455d)
 *
 * Brand theme line colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandLine = {
    primary: palette.brand[600],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/89955e)
 *
 * Alternative brand theme line colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandAltLine = {
    primary: palette.neutral[7],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/85d3b0)
 *
 * Default theme text colours
 *
 * @deprecated Use the `palette` export instead
 */
const text = {
    primary: palette.neutral[7],
    supporting: palette.neutral[46],
    success: palette.success[400],
    error: palette.error[400],
    ctaPrimary: palette.neutral[100],
    ctaSecondary: palette.brand[400],
    ctaTertiary: palette.brand[400],
    anchorPrimary: palette.brand[500],
    anchorSecondary: palette.neutral[7],
    userInput: palette.neutral[7],
    inputLabel: palette.neutral[7],
    inputError: palette.neutral[7],
    inputLabelSupporting: palette.neutral[46],
    inputChecked: palette.brand[400],
    inputHover: palette.brand[400],
    groupLabel: palette.neutral[7],
    groupLabelSupporting: palette.neutral[46],
    newsInverse: palette.news[550],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/244480)
 *
 * Brand theme text colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandText = {
    primary: palette.neutral[100],
    supporting: palette.brand[800],
    success: palette.success[500],
    error: palette.error[500],
    ctaPrimary: palette.brand[400],
    ctaSecondary: palette.neutral[100],
    ctaTertiary: palette.neutral[100],
    anchorPrimary: palette.neutral[100],
    anchorPrimaryHover: palette.brandAlt[400],
    userInput: palette.neutral[100],
    inputLabel: palette.neutral[100],
    inputLabelSupporting: palette.brand[800],
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/11d5fd)
 *
 * Alternative brand theme text colours
 *
 * @deprecated Use the `palette` export instead
 */
const brandAltText = {
    primary: palette.neutral[7],
    supporting: palette.neutral[60],
    ctaPrimary: palette.neutral[100],
    ctaSecondary: palette.neutral[7],
    ctaTertiary: palette.neutral[7],
    anchorPrimary: palette.neutral[7],
};

exports.background = background;
exports.border = border;
exports.brandAltBackground = brandAltBackground;
exports.brandAltBorder = brandAltBorder;
exports.brandAltLine = brandAltLine;
exports.brandAltText = brandAltText;
exports.brandBackground = brandBackground;
exports.brandBorder = brandBorder;
exports.brandLine = brandLine;
exports.brandText = brandText;
exports.line = line;
exports.palette = palette;
exports.text = text;
//# sourceMappingURL=palette.js.map
