'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var breakpoints = require('../breakpoints/breakpoints.js');

const minWidth = (from) => `@media (min-width: ${`${from}px`})`;
const maxWidth = (until) => `@media (max-width: ${`${until - 1}px`})`;
const minWidthMaxWidth = (from, until) => `@media (min-width: ${`${from}px`}) and (max-width: ${`${until - 1}px`})`;
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_media-queries--page#from)
 *
 * @example
 *	const styles = css`
 *		${from.mobileLandscape} {
 *			padding: 0 20px;
 *		}
 * `;
 */
const from = {
    mobile: minWidth(breakpoints.breakpoints.mobile),
    mobileMedium: minWidth(breakpoints.breakpoints.mobileMedium),
    mobileLandscape: minWidth(breakpoints.breakpoints.mobileLandscape),
    phablet: minWidth(breakpoints.breakpoints.phablet),
    tablet: minWidth(breakpoints.breakpoints.tablet),
    desktop: minWidth(breakpoints.breakpoints.desktop),
    leftCol: minWidth(breakpoints.breakpoints.leftCol),
    wide: minWidth(breakpoints.breakpoints.wide),
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_media-queries--page#until)
 *
 * @example
 *	const styles = css`
 *		${until.wide} {
 *			padding: 0 40px;
 *		}
 * `;
 */
const until = {
    mobile: maxWidth(breakpoints.breakpoints.mobile),
    mobileMedium: maxWidth(breakpoints.breakpoints.mobileMedium),
    mobileLandscape: maxWidth(breakpoints.breakpoints.mobileLandscape),
    phablet: maxWidth(breakpoints.breakpoints.phablet),
    tablet: maxWidth(breakpoints.breakpoints.tablet),
    desktop: maxWidth(breakpoints.breakpoints.desktop),
    leftCol: maxWidth(breakpoints.breakpoints.leftCol),
    wide: maxWidth(breakpoints.breakpoints.wide),
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_media-queries--page#betweenand)
 *
 * @example
 *	const styles = css`
 *		${between.phablet.and.desktop} {
 *			padding: 0 32px;
 *		}
 * `;
 */
const between = {
    mobile: {
        and: {
            mobileMedium: minWidthMaxWidth(breakpoints.breakpoints.mobile, breakpoints.breakpoints.mobileMedium),
            mobileLandscape: minWidthMaxWidth(breakpoints.breakpoints.mobile, breakpoints.breakpoints.mobileLandscape),
            phablet: minWidthMaxWidth(breakpoints.breakpoints.mobile, breakpoints.breakpoints.phablet),
            tablet: minWidthMaxWidth(breakpoints.breakpoints.mobile, breakpoints.breakpoints.tablet),
            desktop: minWidthMaxWidth(breakpoints.breakpoints.mobile, breakpoints.breakpoints.desktop),
            leftCol: minWidthMaxWidth(breakpoints.breakpoints.mobile, breakpoints.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints.breakpoints.mobileMedium, breakpoints.breakpoints.wide),
        },
    },
    mobileMedium: {
        and: {
            mobileLandscape: minWidthMaxWidth(breakpoints.breakpoints.mobileMedium, breakpoints.breakpoints.mobileLandscape),
            phablet: minWidthMaxWidth(breakpoints.breakpoints.mobileMedium, breakpoints.breakpoints.phablet),
            tablet: minWidthMaxWidth(breakpoints.breakpoints.mobileMedium, breakpoints.breakpoints.tablet),
            desktop: minWidthMaxWidth(breakpoints.breakpoints.mobileMedium, breakpoints.breakpoints.desktop),
            leftCol: minWidthMaxWidth(breakpoints.breakpoints.mobileMedium, breakpoints.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints.breakpoints.mobileMedium, breakpoints.breakpoints.wide),
        },
    },
    mobileLandscape: {
        and: {
            phablet: minWidthMaxWidth(breakpoints.breakpoints.mobileLandscape, breakpoints.breakpoints.phablet),
            tablet: minWidthMaxWidth(breakpoints.breakpoints.mobileLandscape, breakpoints.breakpoints.tablet),
            desktop: minWidthMaxWidth(breakpoints.breakpoints.mobileLandscape, breakpoints.breakpoints.desktop),
            leftCol: minWidthMaxWidth(breakpoints.breakpoints.mobileLandscape, breakpoints.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints.breakpoints.mobileLandscape, breakpoints.breakpoints.wide),
        },
    },
    phablet: {
        and: {
            tablet: minWidthMaxWidth(breakpoints.breakpoints.phablet, breakpoints.breakpoints.tablet),
            desktop: minWidthMaxWidth(breakpoints.breakpoints.phablet, breakpoints.breakpoints.desktop),
            leftCol: minWidthMaxWidth(breakpoints.breakpoints.phablet, breakpoints.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints.breakpoints.phablet, breakpoints.breakpoints.wide),
        },
    },
    tablet: {
        and: {
            desktop: minWidthMaxWidth(breakpoints.breakpoints.tablet, breakpoints.breakpoints.desktop),
            leftCol: minWidthMaxWidth(breakpoints.breakpoints.tablet, breakpoints.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints.breakpoints.tablet, breakpoints.breakpoints.wide),
        },
    },
    desktop: {
        and: {
            leftCol: minWidthMaxWidth(breakpoints.breakpoints.desktop, breakpoints.breakpoints.leftCol),
            wide: minWidthMaxWidth(breakpoints.breakpoints.desktop, breakpoints.breakpoints.wide),
        },
    },
    leftCol: {
        and: {
            wide: minWidthMaxWidth(breakpoints.breakpoints.leftCol, breakpoints.breakpoints.wide),
        },
    },
};

exports.between = between;
exports.from = from;
exports.until = until;
//# sourceMappingURL=mq.js.map
