/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_size--page#global-size-values) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * May be used for call to action buttons and user input fields.
 */
declare const size: {
    readonly xsmall: 24;
    readonly small: 36;
    readonly medium: 44;
};
declare const iconSize: {
    readonly xsmall: 20;
    readonly small: 26;
    readonly medium: 30;
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * Height tokens expressed in px
 *
 ** `height.ctaMedium`: call to action buttons and links
 ** `height.ctaSmall`: secondary calls to action
 ** `height.ctaXsmall`: calls to action where there is very limited space
 ** `height.inputMedium`: text input fields, radio and checkbox labels
 ** `height.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `height.iconMedium`
 ** `height.iconSmall`
 ** `height.iconXsmall`
 */
declare const height: {
    ctaMedium: 44;
    ctaSmall: 36;
    ctaXsmall: 24;
    inputMedium: 44;
    inputXsmall: 24;
    iconMedium: 30;
    iconSmall: 26;
    iconXsmall: 20;
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * Height tokens expressed in rem
 *
 ** `remHeight.ctaMedium`: call to action buttons and links
 ** `remHeight.ctaSmall`: secondary calls to action
 ** `remHeight.ctaXsmall`: calls to action where there is very limited space
 ** `remHeight.inputMedium`: text input fields, radio and checkbox labels
 ** `remHeight.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remHeight.iconMedium`
 ** `remHeight.iconSmall`
 ** `remHeight.iconXsmall`
 */
declare const remHeight: {
    ctaMedium: number;
    ctaSmall: number;
    ctaXsmall: number;
    inputMedium: number;
    inputXsmall: number;
    iconMedium: number;
    iconSmall: number;
    iconXsmall: number;
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/00ddcb-tokens/t/797660)
 *
 * Width tokens expressed in px
 *
 ** `width.ctaMedium`: medium height call to action buttons and links
 ** `width.ctaSmall`: small height call to action buttons and links
 ** `width.ctaXsmall`: xsmall height call to action buttons and links
 ** `width.inputMedium`: text input fields, radio and checkbox labels
 ** `width.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `width.inputMedium`
 ** `width.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `width.iconMedium`
 ** `width.iconSmall`
 ** `width.iconXsmall`
 */
declare const width: {
    ctaMedium: 44;
    ctaSmall: 36;
    ctaXsmall: 24;
    inputXsmall: 24;
    iconMedium: 30;
    iconSmall: 26;
    iconXsmall: 20;
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/00ddcb-tokens/t/797660)
 *
 * Width tokens expressed in rem
 *
 ** `remWidth.ctaMedium`: medium height call to action buttons and links
 ** `remWidth.ctaSmall`: small height call to action buttons and links
 ** `remWidth.ctaXsmall`: xsmall height call to action buttons and links
 ** `remWidth.inputMedium`: text input fields, radio and checkbox labels
 ** `remWidth.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remWidth.inputMedium`
 ** `remWidth.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remWidth.iconMedium`
 ** `remWidth.iconSmall`
 ** `remWidth.iconXsmall`
 */
declare const remWidth: {
    ctaMedium: number;
    ctaSmall: number;
    ctaXsmall: number;
    inputXsmall: number;
    iconMedium: number;
    iconSmall: number;
    iconXsmall: number;
};
export { size, iconSize, height, remHeight, width, remWidth };
