import { bodySizes, fontWeights, headlineSizes, lineHeights, remBodySizes, remHeadlineSizes, remTextSansSizes, remTitlepieceSizes, textSansSizes, titlepieceSizes } from "./typography/data.js";
type ScaleUnit = 'rem' | 'px';
type LineHeight = keyof typeof lineHeights;
type FontWeight = 'light' | 'regular' | 'medium' | 'bold';
type FontStyle = 'normal' | 'italic';
type FontWeightDefinition = {
    hasItalic: boolean;
};
type Option<A> = A | null;
type TypographyStyles<Unit extends ScaleUnit = ScaleUnit> = {
    fontFamily: string;
    fontSize: Unit extends 'px' ? number : `${number}rem`;
    lineHeight: string | number;
    fontWeight?: typeof fontWeights[keyof typeof fontWeights] | FontWeight;
    fontStyle?: 'normal' | 'italic';
    textDecorationThickness?: number;
};
/** @deprecated will be removed in the next major version */
type TypographySizes = {
    [key in string]: number;
};
type TitlepieceSizes = typeof titlepieceSizes | typeof remTitlepieceSizes;
type HeadlineSizes = typeof headlineSizes | typeof remHeadlineSizes;
type BodySizes = typeof bodySizes | typeof remBodySizes;
type TextSansSizes = typeof textSansSizes | typeof remTextSansSizes;
type AvailableSizes = TitlepieceSizes | HeadlineSizes | BodySizes | TextSansSizes;
type Categories = {
    titlepiece: TitlepieceSizes;
    headline: HeadlineSizes;
    body: BodySizes;
    textSans: TextSansSizes;
};
type Category = keyof Categories;
type AvailableFontWeights = {
    [cat in Category]?: {
        [weight in FontWeight]?: boolean;
    };
};
type ItalicsFontWeights = {
    [cat in Category]?: {
        [weight in FontWeight]?: boolean;
    };
};
type TypographyConfiguration = {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    fontStyle: Option<FontStyle>;
    unit: ScaleUnit;
};
type FontScaleArgs = Partial<Pick<TypographyConfiguration, 'fontWeight' | 'lineHeight' | 'unit'>> & {
    fontStyle?: FontStyle;
};
type FontScaleFunction = (options?: FontScaleArgs) => TypographyStyles;
type FontScaleFunctionStr = (options?: FontScaleArgs) => string;
type TypographyStrFunctions<Sizes extends AvailableSizes> = {
    [key in keyof Sizes]: FontScaleFunctionStr;
};
type TypographyFunctions<Sizes extends AvailableSizes> = {
    [key in keyof Sizes]: FontScaleFunction;
};
/**
 * This is left over from the refactor of the font style method.
 * It is exported from source-foundations but has now been replaced
 * by the fontStyleFunction method type definition.
 *
 * Before we remove it, we need to determine if it is being used.
 *
 * @deprecated will be removed in the next major version
 */
type Fs = <Category extends keyof Categories, Level extends keyof Categories[Category]>(category: Category) => (level: Level, { lineHeight, fontWeight, fontStyle, unit, }: {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    fontStyle: Option<FontStyle>;
    unit: ScaleUnit;
}) => TypographyStyles;
export { ScaleUnit, LineHeight, FontWeight, FontStyle, FontWeightDefinition, Option, TypographyStyles, TypographySizes, TitlepieceSizes, HeadlineSizes, BodySizes, TextSansSizes, AvailableSizes, Categories, Category, AvailableFontWeights, ItalicsFontWeights, TypographyConfiguration, FontScaleArgs, FontScaleFunction, FontScaleFunctionStr, TypographyStrFunctions, TypographyFunctions, Fs };
