import { AvailableFontWeights, ItalicsFontWeights } from "../types-d64e2895.js";
/**
 * Pixel size values for each font that we use in the design system.
 *
 * We assert that the values match the guardian type scale in our
 * {@link [unit test suite](./typography.test.ts)}.
 */
declare const pxTextSizes: {
    readonly textSans: {
        readonly xxsmall: 12;
        readonly xsmall: 14;
        readonly small: 15;
        readonly medium: 17;
        readonly large: 20;
        readonly xlarge: 24;
        readonly xxlarge: 28;
        readonly xxxlarge: 34;
    };
    readonly body: {
        readonly xsmall: 14;
        readonly small: 15;
        readonly medium: 17;
    };
    readonly headline: {
        readonly xxxsmall: 17;
        readonly xxsmall: 20;
        readonly xsmall: 24;
        readonly small: 28;
        readonly medium: 34;
        readonly large: 42;
        readonly xlarge: 50;
    };
    readonly titlepiece: {
        readonly small: 42;
        readonly medium: 50;
        readonly large: 70;
    };
};
/**
 * Relative font sizes, calculated from the pixel sizes above;
 * using the pxToRem method.
 *
 * We assert that the computed rem values match the expected values
 * in our {@link [unit test suite](./typography.test.ts)}.
 *
 * See {@link [pxToRem](../utils/px-to-rem.ts)} for more details.
 */
declare const remTextSizes: {
    readonly textSans: {
        readonly xxsmall: number;
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
        readonly large: number;
        readonly xlarge: number;
        readonly xxlarge: number;
        readonly xxxlarge: number;
    };
    readonly body: {
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
    };
    readonly headline: {
        readonly xxxsmall: number;
        readonly xxsmall: number;
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
        readonly large: number;
        readonly xlarge: number;
    };
    readonly titlepiece: {
        readonly small: number;
        readonly medium: number;
        readonly large: number;
    };
};
declare const fonts: {
    readonly titlepiece: "GT Guardian Titlepiece, Georgia, serif";
    readonly headline: "GH Guardian Headline, Guardian Egyptian Web, Georgia, serif";
    readonly body: "GuardianTextEgyptian, Guardian Text Egyptian Web, Georgia, serif";
    readonly textSans: "GuardianTextSans, Guardian Text Sans Web, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif";
};
/**
 * @see https://theguardian.design/2a1e5182b/p/0578f1-typography-presets/b/4704a2
 * @see https://www.figma.com/file/OqhZwB5nboFn33iHLYoc6d/%E2%97%90-Typography?type=design&node-id=384%3A3&t=mYsLeX87mBF2Uw8J-1
 *
 * Relative units ensure users can change their user-agent’s font size
 * and having the line height grow accordingly.
 *
 * We meet the Web Consortium Accessibility Guidelines’
 * success criterion for “Text Spacing” (1.4.12) as these values
 * can be overridden by users.
 *
 * @see https://www.w3.org/WAI/WCAG21/Understanding/text-spacing
 */
declare const lineHeights: {
    readonly tight: 1.15;
    readonly regular: 1.3;
    readonly loose: 1.4;
};
declare const fontWeights: {
    readonly light: 300;
    readonly regular: 400;
    readonly medium: 500;
    readonly bold: 700;
};
declare const availableFontWeights: AvailableFontWeights;
declare const italicsFontWeights: ItalicsFontWeights;
declare const underlineThickness: {
    readonly textSans: {
        readonly xxsmall: 2;
        readonly xsmall: 2;
        readonly small: 2;
        readonly medium: 2;
        readonly large: 3;
        readonly xlarge: 3;
        readonly xxlarge: 3;
        readonly xxxlarge: 4;
    };
    readonly body: {
        readonly xsmall: 2;
        readonly small: 2;
        readonly medium: 2;
    };
    readonly headline: {
        readonly xxxsmall: 2;
        readonly xxsmall: 3;
        readonly xsmall: 3;
        readonly small: 3;
        readonly medium: 4;
        readonly large: 5;
        readonly xlarge: 6;
    };
    readonly titlepiece: {
        readonly small: 5;
        readonly medium: 6;
        readonly large: 6;
    };
};
declare const textSansSizes: {
    readonly xxsmall: 12;
    readonly xsmall: 14;
    readonly small: 15;
    readonly medium: 17;
    readonly large: 20;
    readonly xlarge: 24;
    readonly xxlarge: 28;
    readonly xxxlarge: 34;
};
declare const bodySizes: {
    readonly xsmall: 14;
    readonly small: 15;
    readonly medium: 17;
};
declare const headlineSizes: {
    readonly xxxsmall: 17;
    readonly xxsmall: 20;
    readonly xsmall: 24;
    readonly small: 28;
    readonly medium: 34;
    readonly large: 42;
    readonly xlarge: 50;
};
declare const titlepieceSizes: {
    readonly small: 42;
    readonly medium: 50;
    readonly large: 70;
};
declare const remBodySizes: {
    readonly xsmall: number;
    readonly small: number;
    readonly medium: number;
};
declare const remTitlepieceSizes: {
    readonly small: number;
    readonly medium: number;
    readonly large: number;
};
declare const remHeadlineSizes: {
    readonly xxxsmall: number;
    readonly xxsmall: number;
    readonly xsmall: number;
    readonly small: number;
    readonly medium: number;
    readonly large: number;
    readonly xlarge: number;
};
declare const remTextSansSizes: {
    readonly xxsmall: number;
    readonly xsmall: number;
    readonly small: number;
    readonly medium: number;
    readonly large: number;
    readonly xlarge: number;
    readonly xxlarge: number;
    readonly xxxlarge: number;
};
export { pxTextSizes, remTextSizes, fonts, lineHeights, fontWeights, availableFontWeights, italicsFontWeights, underlineThickness, textSansSizes, bodySizes, headlineSizes, titlepieceSizes, remBodySizes, remTitlepieceSizes, remHeadlineSizes, remTextSansSizes };
