import { Categories, FontScaleArgs, FontScaleFunction, TypographyConfiguration, TypographyStyles } from "../types-d64e2895.js";
/**
 * Generates a method that returns a TypographyStyles object for a given font scale.
 *
 * **Example**, generate a method that returns styles for the `headline` category
 * at the `small` level and a default font weight of `medium`:
 *
 * ```
 * const headlineSmall =
 * fontStyleFunction('headline', 'small', { fontWeight: 'medium' });
 * ```
 *
 * **Example usage**, we call the method to get our typography styles and override
 * the default font weight set above with `bold`:
 *
 * ```
 * const headlineSmallStyles =
 * headlineSmall({ fontWeight: 'bold' });
 * ```
 */
declare const fontStyleFunction: <Category extends keyof Categories, Level extends keyof Categories[Category]>(category: Category, level: Level, defaults: TypographyConfiguration) => (options?: FontScaleArgs) => TypographyStyles;
/**
 * Generates a method that evaluates a given font scale function with the
 * provided options and returns the typography styles as a CSS string.
 *
 * For an example usage see our {@link [typography string function exports](./index.ts)}.
 *
 * The CSS string exposes a scoped variable: `--source-text-decoration-thickness`,
 * so consumers can use the recommended value for the font/weight combination.
 *
 * For the text underline thickness mappings see {@link underlineThickness}.
 */
declare const fontStyleToStringFunction: (typographyFunction: FontScaleFunction) => (options?: FontScaleArgs) => string;
export { fontStyleFunction, fontStyleToStringFunction };
