/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette)
 *
 * Colour palette organised by type e.g. 'error', or pillar e.g. 'opinion'
 */
declare const palette: {
    readonly brand: {
        readonly 100: "#001536";
        readonly 300: "#041F4A";
        readonly 400: "#052962";
        readonly 500: "#0077B6";
        readonly 600: "#506991";
        readonly 800: "#C1D8FC";
    };
    readonly brandAlt: {
        readonly 200: "#F3C100";
        readonly 300: "#FFD900";
        readonly 400: "#FFE500";
    };
    readonly neutral: {
        readonly 0: "#000000";
        readonly 7: "#121212";
        readonly 10: "#1A1A1A";
        readonly 20: "#333333";
        readonly 38: "#606060";
        readonly 46: "#707070";
        readonly 60: "#999999";
        readonly 86: "#DCDCDC";
        readonly 93: "#EDEDED";
        readonly 97: "#F6F6F6";
        readonly 100: "#FFFFFF";
    };
    readonly error: {
        readonly 400: "#C70000";
        readonly 500: "#FF9081";
    };
    readonly success: {
        readonly 400: "#22874D";
        readonly 500: "#58D08B";
    };
    readonly news: {
        readonly 100: "#660505";
        readonly 200: "#8B0000";
        readonly 300: "#AB0613";
        readonly 400: "#C70000";
        readonly 500: "#FF5943";
        readonly 550: "#FF9081";
        readonly 600: "#FFBAC8";
        readonly 800: "#FFF4F2";
    };
    readonly opinion: {
        readonly 100: "#672005";
        readonly 200: "#8D2700";
        /**
         * @deprecated, use opinion[400]
         */
        readonly 300: "#C74600";
        readonly 400: "#C74600";
        readonly 450: "#E05E00";
        readonly 500: "#FF7F0F";
        readonly 550: "#FF9941";
        readonly 600: "#F9B376";
        readonly 800: "#FEF9F5";
    };
    readonly sport: {
        readonly 100: "#003C60";
        readonly 200: "#004E7C";
        readonly 300: "#005689";
        readonly 400: "#0077B6";
        readonly 500: "#00B2FF";
        readonly 600: "#90DCFF";
        readonly 800: "#F1F8FC";
    };
    readonly culture: {
        readonly 50: "#2B2625";
        readonly 100: "#3E3323";
        readonly 200: "#574835";
        readonly 300: "#6B5840";
        /**
         * @deprecated, use culture[400]
         */
        readonly 350: "#866D50";
        readonly 400: "#866D50";
        readonly 450: "#A1845C";
        readonly 500: "#EACCA0";
        readonly 600: "#E7D4B9";
        readonly 700: "#EFE8DD";
        readonly 800: "#FBF6EF";
    };
    readonly lifestyle: {
        readonly 100: "#510043";
        readonly 200: "#650054";
        readonly 300: "#7D0068";
        readonly 400: "#BB3B80";
        readonly 450: "#F37ABC";
        readonly 500: "#FFABDB";
        readonly 600: "#FEC8D3";
        readonly 800: "#FEEEF7";
    };
    readonly labs: {
        readonly 200: "#0C7A73";
        readonly 300: "#65A897";
        readonly 400: "#69D1CA";
    };
    readonly specialReport: {
        readonly 100: "#222527";
        readonly 200: "#303538";
        readonly 300: "#3F464A";
        readonly 400: "#595C5F";
        readonly 450: "#9DA0A2";
        readonly 500: "#ABC2C9";
        readonly 700: "#E4E5E8";
        readonly 800: "#EFF1F2";
    };
    readonly specialReportAlt: {
        readonly 100: "#2B2B2A";
        readonly 200: "#B9300A";
        readonly 300: "#FF663D";
        readonly 700: "#EBE6E1";
        readonly 800: "#F5F0EB";
    };
    readonly focus: {
        readonly 400: "#0077B6";
    };
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/9280ee)
 *
 * Default theme background colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const background: {
    readonly primary: "#FFFFFF";
    readonly secondary: "#F6F6F6";
    readonly inverse: "#1A1A1A";
    readonly ctaPrimary: "#052962";
    readonly ctaPrimaryHover: "#234B8A";
    readonly ctaSecondary: "#C1D8FC";
    readonly ctaSecondaryHover: "#ACC9F7";
    readonly ctaTertiaryHover: "#E5E5E5";
    readonly input: "#FFFFFF";
    readonly inputChecked: "#0077B6";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/63cc10)
 *
 * Brand theme background colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const brandBackground: {
    readonly primary: "#052962";
    readonly inputChecked: "#FFFFFF";
    readonly ctaPrimary: "#FFFFFF";
    readonly ctaPrimaryHover: "#E0E0E0";
    readonly ctaSecondary: "#506991";
    readonly ctaSecondaryHover: "#234B8A";
    readonly ctaTertiaryHover: "#041F4A";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/743232)
 *
 * Alternative brand theme background colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const brandAltBackground: {
    readonly primary: "#FFE500";
    readonly ctaPrimary: "#121212";
    readonly ctaPrimaryHover: "#454545";
    readonly ctaSecondary: "#F3C100";
    readonly ctaSecondaryHover: "#F2AE00";
    readonly ctaTertiaryHover: "#FFD213";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/69c92f)
 *
 * Default theme border colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const border: {
    primary: "#999999";
    secondary: "#DCDCDC";
    success: "#22874D";
    error: "#C70000";
    ctaTertiary: "#052962";
    input: "#999999";
    inputChecked: "#0077B6";
    inputHover: "#0077B6";
    inputActive: "#0077B6";
    focusHalo: "#0077B6";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/04883b)
 *
 * Brand theme border colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const brandBorder: {
    primary: "#506991";
    secondary: "#506991";
    success: "#58D08B";
    error: "#FF9081";
    ctaTertiary: "#FFFFFF";
    input: "#C1D8FC";
    inputChecked: "#FFFFFF";
    inputHover: "#FFFFFF";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/b/21c6cc)
 *
 * Alternative brand theme border colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const brandAltBorder: {
    ctaTertiary: "#121212";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/593cc9)
 *
 * Default theme line colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const line: {
    primary: "#DCDCDC";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/66455d)
 *
 * Brand theme line colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const brandLine: {
    primary: "#506991";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/89955e)
 *
 * Alternative brand theme line colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const brandAltLine: {
    primary: "#121212";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/85d3b0)
 *
 * Default theme text colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const text: {
    primary: "#121212";
    supporting: "#707070";
    success: "#22874D";
    error: "#C70000";
    ctaPrimary: "#FFFFFF";
    ctaSecondary: "#052962";
    ctaTertiary: "#052962";
    anchorPrimary: "#0077B6";
    anchorSecondary: "#121212";
    userInput: "#121212";
    inputLabel: "#121212";
    inputError: "#121212";
    inputLabelSupporting: "#707070";
    inputChecked: "#052962";
    inputHover: "#052962";
    groupLabel: "#121212";
    groupLabelSupporting: "#707070";
    newsInverse: "#FF9081";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/244480)
 *
 * Brand theme text colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const brandText: {
    primary: "#FFFFFF";
    supporting: "#C1D8FC";
    success: "#58D08B";
    error: "#FF9081";
    ctaPrimary: "#052962";
    ctaSecondary: "#FFFFFF";
    ctaTertiary: "#FFFFFF";
    anchorPrimary: "#FFFFFF";
    anchorPrimaryHover: "#FFE500";
    userInput: "#FFFFFF";
    inputLabel: "#FFFFFF";
    inputLabelSupporting: "#C1D8FC";
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_palette--palette) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/11d5fd)
 *
 * Alternative brand theme text colours
 *
 * @deprecated Use the `palette` export instead
 */
declare const brandAltText: {
    primary: "#121212";
    supporting: "#999999";
    ctaPrimary: "#FFFFFF";
    ctaSecondary: "#121212";
    ctaTertiary: "#121212";
    anchorPrimary: "#121212";
};
declare const brand: {
    readonly 100: "#001536";
    readonly 300: "#041F4A";
    readonly 400: "#052962";
    readonly 500: "#0077B6";
    readonly 600: "#506991";
    readonly 800: "#C1D8FC";
}, brandAlt: {
    readonly 200: "#F3C100";
    readonly 300: "#FFD900";
    readonly 400: "#FFE500";
}, neutral: {
    readonly 0: "#000000";
    readonly 7: "#121212";
    readonly 10: "#1A1A1A";
    readonly 20: "#333333";
    readonly 38: "#606060";
    readonly 46: "#707070";
    readonly 60: "#999999";
    readonly 86: "#DCDCDC";
    readonly 93: "#EDEDED";
    readonly 97: "#F6F6F6";
    readonly 100: "#FFFFFF";
}, error: {
    readonly 400: "#C70000";
    readonly 500: "#FF9081";
}, success: {
    readonly 400: "#22874D";
    readonly 500: "#58D08B";
}, news: {
    readonly 100: "#660505";
    readonly 200: "#8B0000";
    readonly 300: "#AB0613";
    readonly 400: "#C70000";
    readonly 500: "#FF5943";
    readonly 550: "#FF9081";
    readonly 600: "#FFBAC8";
    readonly 800: "#FFF4F2";
}, opinion: {
    readonly 100: "#672005";
    readonly 200: "#8D2700";
    /**
     * @deprecated, use opinion[400]
     */
    readonly 300: "#C74600";
    readonly 400: "#C74600";
    readonly 450: "#E05E00";
    readonly 500: "#FF7F0F";
    readonly 550: "#FF9941";
    readonly 600: "#F9B376";
    readonly 800: "#FEF9F5";
}, sport: {
    readonly 100: "#003C60";
    readonly 200: "#004E7C";
    readonly 300: "#005689";
    readonly 400: "#0077B6";
    readonly 500: "#00B2FF";
    readonly 600: "#90DCFF";
    readonly 800: "#F1F8FC";
}, culture: {
    readonly 50: "#2B2625";
    readonly 100: "#3E3323";
    readonly 200: "#574835";
    readonly 300: "#6B5840";
    /**
     * @deprecated, use culture[400]
     */
    readonly 350: "#866D50";
    readonly 400: "#866D50";
    readonly 450: "#A1845C";
    readonly 500: "#EACCA0";
    readonly 600: "#E7D4B9";
    readonly 700: "#EFE8DD";
    readonly 800: "#FBF6EF";
}, lifestyle: {
    readonly 100: "#510043";
    readonly 200: "#650054";
    readonly 300: "#7D0068";
    readonly 400: "#BB3B80";
    readonly 450: "#F37ABC";
    readonly 500: "#FFABDB";
    readonly 600: "#FEC8D3";
    readonly 800: "#FEEEF7";
}, labs: {
    readonly 200: "#0C7A73";
    readonly 300: "#65A897";
    readonly 400: "#69D1CA";
}, specialReport: {
    readonly 100: "#222527";
    readonly 200: "#303538";
    readonly 300: "#3F464A";
    readonly 400: "#595C5F";
    readonly 450: "#9DA0A2";
    readonly 500: "#ABC2C9";
    readonly 700: "#E4E5E8";
    readonly 800: "#EFF1F2";
}, specialReportAlt: {
    readonly 100: "#2B2B2A";
    readonly 200: "#B9300A";
    readonly 300: "#FF663D";
    readonly 700: "#EBE6E1";
    readonly 800: "#F5F0EB";
}, focus: {
    readonly 400: "#0077B6";
};
export { palette, background, brandBackground, brandAltBackground, border, brandBorder, brandAltBorder, line, brandLine, brandAltLine, text, brandText, brandAltText, brand, brandAlt, neutral, error, success, news, opinion, sport, culture, lifestyle, labs, specialReport, specialReportAlt, focus };
