import { Breakpoint } from "../breakpoints/breakpoints.js";
type BreakpointMap = {
    [key in Breakpoint]: string;
};
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_media-queries--page#from)
 *
 * @example
 *	const styles = css`
 *		${from.mobileLandscape} {
 *			padding: 0 20px;
 *		}
 * `;
 */
declare const from: BreakpointMap;
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_media-queries--page#until)
 *
 * @example
 *	const styles = css`
 *		${until.wide} {
 *			padding: 0 40px;
 *		}
 * `;
 */
declare const until: BreakpointMap;
/**
 * [Storybook](https://guardian.github.io/csnx/?path=/docs/source-foundations_media-queries--page#betweenand)
 *
 * @example
 *	const styles = css`
 *		${between.phablet.and.desktop} {
 *			padding: 0 32px;
 *		}
 * `;
 */
declare const between: {
    mobile: {
        and: {
            mobileMedium: string;
            mobileLandscape: string;
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    mobileMedium: {
        and: {
            mobileLandscape: string;
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    mobileLandscape: {
        and: {
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    phablet: {
        and: {
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    tablet: {
        and: {
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    desktop: {
        and: {
            leftCol: string;
            wide: string;
        };
    };
    leftCol: {
        and: {
            wide: string;
        };
    };
};
export { BreakpointMap, from, until, between };
